@@ -151,6 +151,8 @@ sub prepare_os {
 	$distro =~ s{\s*[-:/,]\s*Version\s*:?\s*}{ };
 	$distro =~ s/\)\s+\(\w+\)\s*$/)/;    # remove architectural part
 	$distro =~ s/\s+\(?(?:i\d86|x86_64)\)?\s*$//; # i386 i486 i586 x86_64
+	$os{VERSION_ID} && $distro !~ m{\b$os{VERSION_ID}\b}i and
+	    $distro .= " $os{VERSION_ID}";
 	}
     elsif ($os{VERSION} && $os{NAME}) {
 	$distro = qq{$os{NAME} $os{VERSION}};
@@ -175,9 +177,10 @@ sub prepare_os {
 	}
     else {
 	# /etc/issue:
-	#  Welcome to SUSE LINUX 10.0 (i586) - Kernel \r (\l).
+	#  Welcome to SUSE LINUX 10.0 "Prague" (i586) - Kernel \r (\l).
+	#  Welcome to openSUSE 10.1 "Agama Lizard" (i586) - Kernel \r (\l).
 	#  Welcome to openSUSE 10.2 (i586) - Kernel \r (\l).
-	#  Welcome to openSUSE 10.2 (X86-64) - Kernel \r (\l).
+	#  Welcome to openSUSE 10.2 "Basilisk Lizard" (X86-64) - Kernel \r (\l).
 	#  Welcome to openSUSE 10.3 (i586) - Kernel \r (\l).
 	#  Welcome to openSUSE 10.3 (X86-64) - Kernel \r (\l).
 	#  Welcome to openSUSE 11.1 - Kernel \r (\l).
@@ -238,6 +241,7 @@ sub prepare_os {
 	$self->{__distro} = $distro;
 	$os .= " [$distro]";
 	}
+    $self->{__release_info} = \%os;
     $self->{__os} = $os;
     } # prepare_os
 
@@ -494,7 +498,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-(c) 2016-2017, Abe Timmerman & H.Merijn Brand, All rights reserved.
+(c) 2016-2021, Abe Timmerman & H.Merijn Brand, All rights reserved.
 
 With contributions from Jarkko Hietaniemi, Campo Weijerman, Alan Burlison,
 Allen Smith, Alain Barbet, Dominic Dunlop, Rich Rauenzahn, David Cantrell.
